@@ -1,8 +1,8 @@
 package Nephia::Response;
 use strict;
 use warnings;
-use utf8;
-
 use parent 'Plack::Response';
 
 1;
+
+__END__
